==> scoutpip-0.1.4.tar.gz: scoutpip-0.1.4/README.md <==
# ``scoutpip``


<p align="center">
  <img src="https://raw.githubusercontent.com/fsorrenti/scoutpip/main/assets/img/scoutpip.jpg"
   width="52%"
 alt="scoutpip_logo"/>
</p>

<div align="center">
  
![](https://img.shields.io/badge/Python-181717?style=plastic&logo=python)
![](https://img.shields.io/badge/Author-Francesco%20Sorrenti%20-181717?style=plastic)

</div>



Hello! Welcome to `scoutpip` (Supernova Cosmology Utilities)! This repositories provide all the codes necessary for computing the multipoles of the SNe luminosity distance and  reproduce the results in https://arxiv.org/pdf/2212.10328, https://arxiv.org/pdf/2403.17741 and https://arxiv.org/pdf/2407.07002,  together with analyses tools. 

## Installation

To install `scoutpip`, follow these steps:
1. (optional) `conda create -n scoutpip python=3.10 jupyter` (create a custom `conda` environment with python 3.10) 
2. (optional) `conda activate scoutpip` (activate it)
3. Install `scoutpip`:

        pip install scoutpip

## Example

Examples can be found in [notebooks](https://github.com/fsorrenti/scoutpip/blob/main/notebooks). 

## Contributing and contacts

Feel free to [fork](https://github.com/fsorrenti/scoutpip/fork) this repository to work on it; otherwise, please [raise an issue](https://github.com/fsorrenti/scoutpip/issues) or contact [Francesco Sorrenti](mailto:francescosorrenti96@gmail.com).

## License

`scoutpip` is released under the GPL-3 license (see [LICENSE](https://github.com/fsorrenti/scoutpip/blob/main/LICENSE.txt)) subject to the non-commercial use condition.

     scout
     Copyright (C) 2025 Francesco Sorrenti & contributors

     This program is released under the GPL-3 license (see LICENSE.txt), subject to a non-commercial use condition.

==> scoutpip-0.1.5.tar.gz: scoutpip-0.1.5/README.md <==
# ``scoutpip``


<p align="center">
  <img src="https://raw.githubusercontent.com/fsorrenti/scoutpip/main/assets/img/scoutpip.jpg"
   width="52%"
 alt="scoutpip_logo"/>
</p>

<div align="center">
  
![](https://img.shields.io/badge/Python-181717?style=plastic&logo=python)
![](https://img.shields.io/badge/Author-Francesco%20Sorrenti%20-181717?style=plastic)

</div>



Hello! Welcome to `scoutpip` (Supernova Cosmology Utilities pip-installable)! This repositories provide all the codes necessary for computing the multipoles of the SNe luminosity distance and  reproduce the results in https://arxiv.org/pdf/2212.10328, https://arxiv.org/pdf/2403.17741 and https://arxiv.org/pdf/2407.07002,  together with analyses tools. 

## Installation

To install `scoutpip`, follow these steps:
1. (optional) `conda create -n scoutpip python=3.10 jupyter` (create a custom `conda` environment with python 3.10) 
2. (optional) `conda activate scoutpip` (activate it)
3. Install `scoutpip`:

        pip install scoutpip

## Example

Examples can be found in [notebooks](https://github.com/fsorrenti/scoutpip/blob/main/notebooks). 

## Contributing and contacts

Feel free to [fork](https://github.com/fsorrenti/scoutpip/fork) this repository to work on it; otherwise, please [raise an issue](https://github.com/fsorrenti/scoutpip/issues) or contact [Francesco Sorrenti](mailto:francescosorrenti96@gmail.com).

## Citation
If you use `scoutpip`, please cite the corresponding paper:

    @artiicle{Sorrenti:2024ztg,
        author = "Sorrenti, Francesco and Durrer, Ruth and Kunz, Martin",
        title = "{The low multipoles in the Pantheon+SH0ES data}",
        eprint = "2403.17741",
        archivePrefix = "arXiv",
        primaryClass = "astro-ph.CO",
        month = "3",
        year = "2024"
    }


## License

`scoutpip` is released under the GPL-3 license (see [LICENSE](https://github.com/fsorrenti/scoutpip/blob/main/LICENSE.txt)) subject to the non-commercial use condition.

     scout
     Copyright (C) 2025 Francesco Sorrenti & contributors

     This program is released under the GPL-3 license (see LICENSE.txt), subject to a non-commercial use condition.
